ConfigurationError

Struct ConfigurationError 

pub struct ConfigurationError { /* private fields */ }
Represents all errors that might occur at all stages of processing configuration.

Implementations

Source

impl ConfigurationError

pub fn inner(&self) -> &ErrorCode

Returns reference to underlying error code. Returned object has all contextual information stripped off.

pub fn enrich_with_context<T: Display>(self, message: T) -> Self

Enriches error context with arbitray message.

Used to put more contextual information in the error to facilitate debugging issues. One can put e.g. path to file that failed to open in error message this way.

Example
use miau::error::{ConfigurationError, ErrorCode};

let error: ConfigurationError = ErrorCode::NullValue.into();

let enriched_error = error
    .enrich_with_context("Detailed description of contextual information");
pub fn enrich_with_key(self, key: Key) -> Self

Enriches error context with a key.

Used to put more contextual information in the error to facilitate debugging issues. One can put information about location in configuration tree in error with this function.

Example
use miau::error::{ConfigurationError, ErrorCode};
use miau::configuration::Key;

let error: ConfigurationError = ErrorCode::NullValue.into();

let enriched_error = error
    .enrich_with_key(Key::Map("key".to_string()));
pub fn enrich_with_keys(self, keys: &CompoundKey) -> Self

Enriches error context with a complex path.

Used to put more contextual information in the error to facilitate debugging issues. One can put information about location in configuration tree in error with this function.

pub fn pretty_display(&self) -> PrettyConfigurationDisplay<'_>

Returns an object that displays error in pretty way.

Example
use miau::error::{ConfigurationError, ErrorCode};
use miau::configuration::Key;

let error: ConfigurationError = ErrorCode::NullValue.into();

println!("Basic display : {}", error);
println!("Pretty display : {}", error.pretty_display());

Methods from Deref<Target = ErrorImpl>

pub fn get_code(&self) -> &ErrorCode

Returns reference to underlying cause of the error.

pub fn get_path(&self) -> Option<&[Key]>

Returns path in configuration at which error occured.

Returned value is a slice with configuration keys counting from root.

pub fn get_context(&self) -> Option<&[String]>

Returns additional context attached to error.

This information can contain, for instance, name of the file that was not found.